@@ -402,6 +402,7 @@ def display2(videodev, save = False,
         BPStag = dt.datetime.now()
         FPS = 0
         FPSlast = 0
+        frames_total = 0
 
         senh = Stream_Enhancer()
         saved_jpg = False
@@ -478,8 +479,17 @@ def display2(videodev, save = False,
                 #print(frame)
 
                 wname = videodev
-                cv2.namedWindow( wname, cv2.WINDOW_KEEPRATIO)
-                cv2.resizeWindow(wname, frame.shape[1], frame.shape[0] )
+
+                frames_total+= 1
+                # cv2.namedWindow( wname, cv2.WINDOW_KEEPRATIO ,cv2.WINDOW_GUI_EXPANDED)
+                cv2.namedWindow( wname , cv2.WINDOW_KEEPRATIO ) # 2 may allow resize on gigavg
+                if frames_total < 2:
+                    #cv2.namedWindow(wname,cv2.WND_PROP_FULLSCREEN)
+                    # ?https://stackoverflow.com/questions/62870031/pixel-coordinates-and-colours-not-showing
+                    # TRICK !!!!!!!!!!!!
+                    # https://stackoverflow.com/a/52776376
+                    cv2.setWindowProperty(wname, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN)
+                    cv2.resizeWindow(wname, frame.shape[1], frame.shape[0] )
 
                 if save:
                     # print("AVI")
@@ -498,7 +508,7 @@ def display2(videodev, save = False,
                     frame = cv2.rotate(frame, cv2.ROTATE_180)
                     #frame = cv2.rotate(frame, cv2.ROTATE_90_CLOCKWISE)
 
-                cv2.imshow(rpi_name, frame, ) # 1 window for each RPi
+                cv2.imshow(rpi_name, frame ) # 1 window for each RPi
                 #cv2.setWindowProperty(rpi_name, cv2.WND_PROP_TOPMOST, 1)
                 # cv2.namedWindow(rpi_name, cv2.WINDOW_GUI_EXPANDED)
                 # time.sleep(0.2)
